@@ -1,13 +1,14 @@
 """The organization resource."""
 
 from __future__ import unicode_literals
-from . import Resource, Sensor, User, Element
+from . import Resource, Sensor, User, Element, Label
 from . import to_many, timeseries, metadata
 
 
 @to_many(User)
 @to_many(Element)
 @to_many(Sensor)
+@to_many(Label)
 @timeseries()
 @metadata()
 class Organization(Resource):
